bcrypt_elixir v2.1.0 Bcrypt.Base View Source
Base module for the Bcrypt password hashing library.
Link to this section Summary
Functions
Verify the password by comparing it with the stored hash.
Generate a salt for use with Bcrypt.
Hash the password and salt with the Bcrypt hashing algorithm.
Hash a password using Bcrypt.
Link to this section Functions
Link to this function
checkpass_nif(password, stored_hash) View Source
Verify the password by comparing it with the stored hash.
Link to this function
gensalt_nif(random, log_rounds, minor) View Source
Generate a salt for use with Bcrypt.
Link to this function
hash_nif(password, salt) View Source
Hash the password and salt with the Bcrypt hashing algorithm.
Link to this function
hash_password(password, salt) View Source
Hash a password using Bcrypt.
Link to this function